@@ -112,18 +112,12 @@ function sqimap_getacl($imap_stream, $mb_name, &$out) {
  * @param object $imap_stream The IMAP stream
  * @param string $mailbox str Mailbox to get the ACL for
  * @return string ACL String
- * @todo Use sqimap_run_command instead of fputs()
  */
 function sqimap_myrights($imap_stream, $mailbox) {
 
 	$aclflag=1; $tmp_pos=0;
 	$query = "MYRIGHTS \"$mailbox\"";
-
-	//sqimap_run_command($imap_stream, $query, true, $response,
-	//  $message, false, false, false, false);
-	  
-	fputs ($imap_stream, "a001 MYRIGHTS \"$mailbox\"\r\n");
-	$output = sqimap_read_data ($imap_stream, 'a001', true, $result, $message);
+	$output = sqimap_run_command ($imap_stream, $query, false, $response, $message);
 	$output = explode(" ", $output[0]);
 	
 	$i = sizeof($output)-2;
